LexEd
=====

|build| |python3.6| |pypi| |license|

python + ncurses based console text editor

Resurrection
------------

Former pyWarrior by T.Davis has been massively reworked.

There's still a lot to do though.

Install
-------

::

    $ pip install lexed

Usage
-----

::

    $ lexed

.. |build| image:: https://travis-ci.org/lexycore/lexed.svg?branch=master
   :target: https://travis-ci.org/lexycore/lexed
.. |python3.6| image:: https://img.shields.io/pypi/pyversions/lexed.svg
   :target: https://pypi.org/project/lexed/
.. |pypi| image:: https://img.shields.io/pypi/v/lexed.svg
   :target: https://pypi.org/project/lexed/
.. |license| image:: https://img.shields.io/pypi/l/lexed.svg
   :target: https://github.com/lexycore/lexed/blob/master/LICENSE
